@@ -4,7 +4,6 @@ import logging
 
 from arrlio.models import TaskInstance, TaskResult
 
-
 logger = logging.getLogger("arrlio.plugins.base")
 
 
@@ -12,18 +11,20 @@ class Plugin(abc.ABC):
     def __init__(self, app):
         self.app = app
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def name(self) -> str:
         pass
 
     async def on_init(self):
-        logger.info(f"Plugin[{self.name}] initialization done")
+        logger.info("Plugin[%s] initialization done", self.name)
 
     async def on_close(self):
         pass
 
     @contextlib.asynccontextmanager
     def task_context(self, task_instance: TaskInstance):
+        # pylint: disable=unused-argument
         yield
 
     async def on_task_send(self, task_instance: TaskInstance) -> None:
